==> optaweb-employee-rostering-distribution-7.58.0.Final.zip: optaweb-employee-rostering-distribution-7.58.0.Final/sources/optaweb-employee-rostering-backend/src/test/java/org/optaweb/employeerostering/admin/AdminRestControllerTest.java <==
/*
 * Copyright 2019 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.optaweb.employeerostering.admin;

import static org.assertj.core.api.Assertions.assertThat;

import org.junit.Test;
import org.junit.runner.RunWith;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.test.autoconfigure.jdbc.AutoConfigureTestDatabase;
import org.springframework.boot.test.context.SpringBootTest;
import org.springframework.boot.test.web.client.TestRestTemplate;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.test.context.junit4.SpringRunner;

@RunWith(SpringRunner.class)
@SpringBootTest(webEnvironment = SpringBootTest.WebEnvironment.DEFINED_PORT)
@AutoConfigureTestDatabase
public class AdminRestControllerTest {

    @Autowired
    private TestRestTemplate restTemplate;

    private final String adminPathURI = "http://localhost:8080/rest/admin/";

    private ResponseEntity<Void> resetApplication() {
        return restTemplate.postForEntity(adminPathURI + "reset", null, Void.class);
    }

    @Test
    public void resetApplicationTest() {
        ResponseEntity<Void> resetResponse = resetApplication();
        assertThat(resetResponse.getStatusCode()).isEqualTo(HttpStatus.OK);
    }
}

==> optaweb-employee-rostering-distribution-8.3.0.Final.zip: optaweb-employee-rostering-distribution-8.3.0.Final/sources/optaweb-employee-rostering-backend/src/test/java/org/optaweb/employeerostering/admin/AdminRestControllerTest.java <==
/*
 * Copyright 2019 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.optaweb.employeerostering.admin;

import static org.assertj.core.api.Assertions.assertThat;

import org.junit.jupiter.api.Test;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.test.autoconfigure.jdbc.AutoConfigureTestDatabase;
import org.springframework.boot.test.context.SpringBootTest;
import org.springframework.boot.test.web.client.TestRestTemplate;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;

@SpringBootTest(webEnvironment = SpringBootTest.WebEnvironment.DEFINED_PORT)
@AutoConfigureTestDatabase
public class AdminRestControllerTest {

    @Autowired
    private TestRestTemplate restTemplate;

    private final String adminPathURI = "http://localhost:8080/rest/admin/";

    private ResponseEntity<Void> resetApplication() {
        return restTemplate.postForEntity(adminPathURI + "reset", null, Void.class);
    }

    @Test
    public void resetApplicationTest() {
        ResponseEntity<Void> resetResponse = resetApplication();
        assertThat(resetResponse.getStatusCode()).isEqualTo(HttpStatus.OK);
    }
}
